%% Paper: VEXPA: Validated EXPonential Analysis through regular sub-sampling.pdf
%
% Matteo Briani, Annie Cuyt and Wen-shin Lee 
%
% VEXPA: Validated EXPonential Analysis through regular 
% sub-sampling
%
% Example Figure 1.
%

%% Script environment
% This script depends on the random number generator state.

clear  
close all

%% Example Figure 1.
% In Figure 1 we show the results of the analysis of a test 
% signal perturbed by a large number of independent noise 
% realizations: the true $\lambda_i$ are forming clusters while 
% the ones related to noise are scattered around [2, 20]. In 
% addition, around each $\lambda_i$-cluster one empirically finds
% an almost Froissart doublet-free zone.

b = exp(2*pi*1i./(360./[8,25,91,185,220,278,295,305,322,357]));
c = ones(size(b));
params = MultiExponentialParameters(1,{b,c},'normalized');

bsolver = BSolverGEP('--nsamples',60);
                       
figure
plot_unit_circle('--width',2)
hold on
for k = 1:50
    signal = params.construct(1000);
    signal.add_white_gaussian_noise(30,'db');
    B = bsolver.solve(signal);
    plot(B,'k.','MarkerSize',3);
end
plot(b,'ro','LineWidth',2,'MarkerSize',7)
title(['Figure 1. Analysis results (n = 10, \nu = 30) of test'... 
       ' signal \phi(t) after several perturbations'...
       ' \epsilon(z): the true \lambda_i are drawn as red'...
       ' circles.'])