%% Paper: VEXPA: Validated EXPonential Analysis through regular sub-sampling.pdf
%
% Matteo Briani, Annie Cuyt and Wen-shin Lee 
%
% VEXPA: Validated EXPonential Analysis through regular 
% sub-sampling
%
% Example Figure 2.
%

%% Script environment
% This script does not depend on the random number generator state.

clear  
close all

%% Example Figure 2.
% In Figure 2 we illustrate the relationship between the $\rho_i$ 
% and the relative position of the $\lambda_i$ with respect to 
% each other. For our toy problem we choose $\Omega = 100, n = 10,
% \alpha_i = 1, \mu_i = \mathrm{i}2\pi(i - 1)$. At the left the values 
% $\rho_i$ are plotted at the locations of the generalized 
% eigenvalues $\lambda_i = \exp(\mu_i/\Omega),i=1,\dots,n$. When 
% changing the undersampling parameter $u$ in $^s_uH_n$ in (4) 
% and (8) from $u = 1$ to $u = 10$ and recomputing the 
% generalized eigenvalues $\exp(10\mu_i/\Omega)$ and the disposedness,
% which we now denote by $_u\rho_i$, the result, which is shown 
% at the right, changes dramatically. Actually, taking $u > 1$ is 
% equivalent to replacing $\Delta$ by $u\Delta$ or replacing $\Omega$
% by $\Omega/u$.

b = exp(2*pi*1i*(0:9)/100);
bu = exp(2*pi*1i*(0:9)/10);
c = ones(size(b));

params = MultiExponentialParameters(1/100,{b,c},'normalized');
paramsu = MultiExponentialParameters(1/100,{bu,c},'normalized');

plot3_base_terms(params,'--z','ill-disposedness');
title(['Figure 2. (left) Ill-disposed \lambda_i = exp(i2\pi'...
       '(i-1)/100), i=1,...,10.'])
   
plot3_base_terms(paramsu,'--z','ill-disposedness');
title(['Figure 2. (right) well-disposed _1_0\lambda_i = exp('...
       'i2\pi(i-1)/10), i=1,...10.'])