%% Paper: VEXPA: Validated EXPonential Analysis through regular sub-sampling.pdf
%
% Matteo Briani, Annie Cuyt and Wen-shin Lee 
%
% VEXPA: Validated EXPonential Analysis through regular 
% sub-sampling
%
% Example Figure 4.
%

%% Script environment
% This script does not depend on the random number generator state.

clear  
close all

%% Example Figure 4.
% In Figure 4 we graphically sketch what happens. There $u = 9$, 
% the elements in $U_i$ are shown using blue circles, $s = 4$, 
% the elements in $S_i$ are shown using green squares and the 
% arrow points to the unique non-aliased $\lambda_i$ in their 
% intersection. The orange portion is the region where the 
% aliased $_u\lambda_i$ lies (red square), from which we have to 
% recover the correct $\lambda_i$, the aliasing being the 
% consequence of the decimation of the collected samples
% by a factor $u$.

mu = 6.4*pi*1i;
r = 0.1;

u = 9;
s = 4;
Ui = exp(mu*r+2*pi*1i/u*(0:u-1)); 
Si = exp(mu*r+2*pi*1i/s*(0:s-1));

plot_unit_circle
hold on
plot(Ui,'bo','MarkerSize',10,'LineWidth',1.5)
plot(Si,'gs','MarkerSize',10,'LineWidth',2)
plot(Ui([1,7]),'rs','MarkerSize',20,'LineWidth',3)
t = linspace(-pi/9,pi/9,100);
plot(polyshape([0,cos(t),0],[0,sin(t),0]),'FaceColor',[1,0.5,0])
quiver(real(Ui(7)),imag(Ui(7)),real(Ui(1)-Ui(7)),...
       imag(Ui(1)-Ui(7)),'Color','k','LineWidth',2,...
       'MaxHeadSize',0.5)
title({['Figure 4. Intersection of U_i (blue circles, u=9) '...
        'and S_i (green'], ['squares, s=4), relocating the '...
        'aliased _u\lambda_i (red square).']})